# copyright 1999 McMillan Enterprises
# license: use as you please. No warranty.
#
# Utility to create a very simple config file
# and build a single file executable for a script.
#
# If your script requires anything outside the *.py, *.pyd and *.dll
# dependencies, you'll need to build the config file yourself.
#
# Oh, yes. This does support Tk automatically.
#
# Copied from Simple.py
#
# Changed by Thomas Heller: Does not overwrite existing file
# without confirmation.

import os
import sys
import string

tmplt = """\
[MYSINGLEFILE]
name= %(basename)s.exe
type= FULLEXE
userunw = %(tk)d
zlib= MYZLIB
misc = %(misc)s
script= %(scripts)s
debug = %(debug)d

[MYZLIB]
type = PYZ
name= %(basename)s.pyz
dependencies= %(scripts)s
excludes= dospath, posixpath, macpath
includes=
"""

def create(sname, home, tk, debug):
    workdir, script = os.path.split(sname)
    basenm, ext = os.path.splitext(script)
    cfgfile = os.path.join(workdir, basenm + '.cfg')
    if os.path.exists (cfgfile):
        answer = ''
        while answer not in ('y', 'Y', 'n', 'N'):
            answer = raw_input ("File '%s' already exists. Overwrite? [yn]" % cfgfile)
            if answer in ('n', 'N'):
                sys.exit (1)
    misc = ''
    scripts = script
    if tk:
        misc = 'TK'
        scripts = 'unpackTK.py, runTK.py, %s' % script
    cfg = open(cfgfile, 'w').write(tmplt % {'basename':basenm,
                                            'pyinsthome':home,
                                            'misc':misc,
                                            'scripts':scripts,
                                            'tk':tk,
                                            'debug':debug})
    tkcfg = ''
    if tk:
        tkcfg = os.path.join(home, 'projects', 'buildTK', 'tk.cfg')
    cmd = '%s %s %s %s' % (q(sys.executable),
                        q(os.path.join(home, 'Builder.py')),
                        q(cfgfile), q(tkcfg))
    print '>',cmd
    os.system(cmd)

def q(s):
    if string.find(s, ' ') > -1:
        return '"'+s+'"'
    return s
 
if __name__ == '__main__':
    if len(sys.argv) < 2:
        print "Usage: python %s <scriptname>.py [options]" % sys.argv[0]
        print " options = [-tk]"
        print "      tk -> install a private TCL/TK for use by the app"
    else:
        tk = debug = 0
        home = os.path.dirname(sys.argv[0])
        if home == '':
            home = '.'
        home = os.path.abspath(home)
        if "-tk" in sys.argv:
            tk = 1
        if "-d" in sys.argv:
            debug = 1
        create(sys.argv[1], home, tk, debug)
            
